.\" -*- nroff -*-
.\" Copyright (c) 1996 by Yoshishige Arai.  All right reserved.
.\"
.\" 1. This software is a Freeware and is provided ``AS IS'', without
.\" any warranty.
.\" 2. Redistribution and use in source, with or without modification,
.\"    are permitted provided that the following conditions are met.
.\" 3. Redistributions of source code must retain the above copyright
.\"    notice.
.\" 4. This package must redistribute for free, advertising materials
.\"    must not include this software without prior written permisson
.\"    from the author.
.\" 5. The latest version of this software is available at:
.\"    http://www.on.rim.or.jp/~ryo2/fsw.html
.\" 6. Notify to the author before redistribution 
.\"     $Id: potato.man,v 1.3 1997/08/30 13:44:54 ryo2 Exp $
.\"
.Dd August 30, 1997
.Dt POTATO 1
.Sh NAME
.Nm potato
.Nd retrieve files from remote-host using http protocol
.Sh SYNOPSIS
.Nm potato
.Op Fl A
.Op Fl a
.Op Fl c
.Op Fl g Ar num
.Op Fl i
.Op Fl I Ar EXT1,EXT2,..EXTn
.Op Fl n
.Op Fl p Ar http://SERVER:PORT
.Op Fl P Ar "SERVER1,SERVER2,.."
.Op Fl r
.Op Fl x
.Op Fl y
.Op Fl q
.Ar URL
.Ar Destination_Directory
.Nm potato
.Op Fl h
.Sh DESCRIPTION
.Nm potato
allows a user to transfer files recursively from a remote network
site using http protocol.
.Ar URL
may be of the form 
.Em http://site.domain/path/file
.Pp
The following options are available:
.Pp
.Bl -tag -width Ds
.It Fl A
retrieve all the files regardless of the suffix.
.It Fl a
Following suffixes of the linked files may be allowed to retrieve:
.Pp
.Bd -tag -width Ds -compact -offset indent
lzh, zip, tar, gz, tgz, taz, Z, z, arc, zoo, exe, hqx, Hqx, sea, sit
.Pp
If you want to get files which have an another suffix, use
.Fl I
option or add the suffix to the list @arcExt in the source.
.Ed
.It Fl c
.Nm potato
ignore the links to CGI program, but retrieves an output of CGI
program as HTML with this option.
.It Fl g Ar num
Since 
.Nm potato
sets the modification time of retrieved files same as that of the remote
host if the 'Last-modified' header is returns from WWW server,
if the file already exists in the destination directory
and is identical to the file at the remote host,
the local file will be read instead of transfering from WWW server
and be used to get links.
(default
.Fl g Ar 3
)
.Pp
The argument means the way to compare as follows:
.Bl -tag -width Ds -compact -offset indent
.It Ar 1
The local file is regarded as identical when its modification time is
equal or newer than that of the remote host.
.It Ar 2
The local file is regarded as identical when its size is equal to
compare with the file of the remote host.
.It Ar 3
The local file is regarded as identical when its modification time is
equal or newer, and/or its size is equal to compare with the file of
the remote host.
.It Ar 4
The local file is regarded as identical forcedly without comparing to
the remote one and will be read to get link tags.
.El
.It Fl i
includes the suffixes gif, GIF, jpg, jpeg, JPG, ps, and PS to retrieve.
If your want to retrieve files with an another suffix, use
.Fl I
option or add the new one to the list '@imageExt' in the source.
.It Fl I Ar EXT1,EXT2,..EXTn
includes the suffixes specified as EXT1,EXT2,.. and EXTn with the
target suffixes to retrieve.
.It Fl n
force PROXY server to refresh its cache with "no-cache pragma".
.It Fl p Ar http://SERVER:PORT
connect via PROXY server.
.Fl p
takes priority over 'http_proxy'.
Particularly if
.Fl p Ar no
is set, environment strings 'http_proxy' will be ignored and won't use
PROXY.
.It Fl P Ar "SERVER1,SERVER2,.."
sets the server
.Ar SERVER1,SERVER2,..
to ignore PROXY and to connect directly even if PROXY is set to use.
.It Fl r Ar N
sets the recursive depth as the argument
.Ar N .
If it's not specified, then all the links under the directory of
.Ar URL
will be retrieved.
.Pp
Add
.Fl r Ar 0
to get the specified URL only.
Note to use with
.Fl A
option, if you don't want to pay attension of extension of the URL.
.It Fl x Ar filename
change the default welcome page that will be used to save in the local 
disk, when URL has only the directory name.
The default filename is 'index.html'.
.It Fl y Ar user:password
specify user ID and password to send, when authentication was
required by the WWW server for the connection.
.It Fl q
silent mode.
.It Fl h
brief help
.El
.Pp
.Sh EXAMPLE
The command:
.Bd -literal -offset indent
potato -i -y USER:PASSWORD http://server_name/subj/ /tmp/sub
.Ed
.Pp
retrieves all the file linked from http://server_name/subj/index.html
and save those into the directory /tmp/sub. USER and PASSWORD will be
used for the authentication.
.Pp
The command:
.Bd -literal -offset indent
potato -A -g 2 -p http://proxy_server:8080 http://server_name/subj
.Pp
.Ed
retrieve all the file linked from http://server_name/subj/index.html
via PROXY, but read local file as a local cache when the corresponding 
file in the remote host has the same size.
.Pp
The command:
.Bd -literal -offset indent
potato -a -r 0 http://foo.com/archives/bar.tar.gz /tmp
.Ed
.Pp
retrieve only bar.tar.gz and save it in the directory /tmp
.Pp
.Sh ENVIRONMENTAL VARIABLES
The following environment variable affect the execution of
.Nm potato .
.Bl -tag -width http_proxy
.It Ev http_proxy
specify the server name and port number thus
http://server_name:number/ to access via PROXY server.
.It Ev no_proxy
specify the server name to connect directly without PROXY.
.Pp
.Sh NOTES
If there is a 'Last-modified' line in the header received from the WWW 
server, the local file to save at the local host will be adjusted as
the same modification time, but if it isn't included, saved time will
be used.  Note that the Web pages which uses Server Side Includes
don't have 'Last-modified' and 'Content-length' headers, so -g options
will be ineffective.
In addition to there may be strange time formats in some Web's header
so that -g option may not work correctly on such a server.
Please mail to <ryo2@on.rim.or.jp> if you  find those wrong behavior.
